#!/usr/bin/python

# Copyright (C) 2014 Paul Kocialkowski <contact@paulk.fr>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys

replicant_size = [
	# Vertical
	[ 5024, 8000 ],
	# Horizontal
	[ 30107, 8000 ]
]

def scale_vertical(width, height):
	k = 90
	value = (replicant_size[0][0] * height * k) / (100 * replicant_size[0][1])

	while value > width and k > 0:
		k -= 10
		value = (replicant_size[0][0] * height * k) / (100 * replicant_size[0][1])

	return [ value, height * k / 100 ]

def scale_horizontal(width, height):
	k = 90
	value = (replicant_size[1][1] * width * k) / (100 * replicant_size[1][0])

	while value > height and k > 0:
		k -= 10
		value = (replicant_size[1][1] * width * k) / (100 * replicant_size[1][0])

	return [ width * k / 100, value ]

def scale(width, height, orientation):
	if orientation == "v":
		size = scale_vertical(width, height)
	elif orientation == "h":
		size = scale_horizontal(width, height)
	else:
		print("Invalid orientation: "+orientation)
		return -1

	x = (width - size[0]) / 2
	y = (height - size[1]) / 2

	print("Width: "+str(size[0]))
	print("Height: "+str(size[1]))
	print("X: "+str(x))
	print("Y: "+str(y))

	return 0

if len(sys.argv) < 4:
	print("Usage: "+sys.argv[0]+" [WIDTH] [HEIGHT] [ORIENTATION]")
	exit(1)

scale(int(sys.argv[1]), int(sys.argv[2]), sys.argv[3].lower()[0])
